#!/bin/env python3
# -*- fill-column: 120; indent-tabs-mode: nil; tab-width: 10; python-indent-offset: 2 -*-

# Common utilities
import json
import subprocess

# Returns a (string) process output, or None for failure
def get_process_output(cmd, logapi):
  cmdname = cmd[0]
  ret = subprocess.run(cmd, capture_output=True)
  if ret.returncode != 0:
    errstr = ""
    try:
      errstr = ": " + ret.stderr.decode("utf-8")
    except:
      pass
    logapi.log(f"command {cmd} returned failure {ret.returncode}{errstr}")
    return None
  try:
    return ret.stdout.decode("utf-8")
  except:
    logapi.log(f"command {cmd} returned invalid utf-8")
    return None

# Returns a json-object parsed from a process's output, or None for failure
def get_process_output_json(cmd, logapi):
  ret = get_process_output(cmd, logapi)
  if ret is None:
    return ret
  try:
    return json.loads(ret)
  except:
    logapi.log(f"command {cmd[0]} returned invalid JSON: {ret}")
    return None
